@@ -666,20 +666,36 @@ def solve(f, *symbols, **flags):
     """
     from sympy.solvers.solvers import solve
     from IPython.display import display
-    if isinstance(f, Equation):
-        flags['dict'] = True
-        result = solve(f.lhs - f.rhs, *symbols, **flags)
-        solns = []
-        # return result
+    newf =[]
+    solns = []
+    contains_eqn = False
+    if hasattr(f,'__iter__'):
+        for k in f:
+            if isinstance(k, Equation):
+                newf.append(k.lhs-k.rhs)
+                contains_eqn = True
+            else:
+                newf.append(k)
+    else:
+        if isinstance(f, Equation):
+            newf.append(f.lhs - f.rhs)
+            contains_eqn = True
+        else:
+            newf.append(f)
+    flags['dict'] = True
+    result = solve(newf, *symbols, **flags)
+    if contains_eqn:
         for k in result:
             for key in k.keys():
                 val = k[key]
                 tempeqn = Eqn(key, val)
                 display(tempeqn)
                 solns.append(tempeqn)
-        return solns
     else:
-        return solve(f, *symbols, **flags)
+        solns = result
+    return solns
+    # else:
+    #     return solve(f, *symbols, **flags)
 
 def sqrt(arg, evaluate = None):
     """
@@ -711,7 +727,7 @@ def root(arg, n, k = 0, evaluate = None):
         return Equation(symroot(arg.lhs, n, k, evaluate), symroot(arg.rhs,
                                                             n, k, evaluate))
     else:
-        return symsqrt(arg, n, k, evaluate)
+        return symroot(arg, n, k, evaluate)
 
 # pick up the docstring for root from sympy
 from sympy.functions.elementary.miscellaneous import root as symroot
@@ -732,6 +748,23 @@ def collect(expr, syms, func=None, evaluate=None, exact=False,
         return collect(expr, syms, func, evaluate, exact,
                        distribute_order_term)
 
+class Eq(Eq):
+    """
+    Extension of Equality class to include the ability to convert it to an
+    Equation.
+    """
+    def to_Equation(self):
+        """
+        Return: recasts the Equality as an Equation.
+        """
+        return Equation(self.lhs,self.rhs)
+
+    def to_Eqn(self):
+        """
+        Synonym for to_Equation.
+        Return: recasts the Equality as an Equation.
+        """
+        return self.to_Equation()
 
 #####
 # Extension of the Function class. For incorporation into SymPy this should
